import bcrypt from "bcrypt";
import { Request, Response } from "express";
import jwt from "jsonwebtoken";
import envVars from "../config";
import Worker from "../db/models/Worker";

const authLoginController = async (req: Request, res: Response) => {
  try {
    const { email, password } = req.body;

    const worker = await Worker.findOne({
      attributes: ["email", "password", "role"],
      where: {
        email: email,
      },
    });

    if (!worker) {
      return res.status(401).json({ success: false, error: "invalidEmail" });
    }

    const isPasswordCorrect = await bcrypt.compare(password, worker.password);

    if (isPasswordCorrect) {
      const payload = {
        email: worker.email,
        role: worker.role,
      };

      const token = jwt.sign(payload, envVars.JWT_SECRET);

      return res.cookie("token", token).json({ success: true });
    } else {
      return res.status(401).json({ success: false, error: "invalidPassword" });
    }
  } catch (error) {
    console.error("server error: ", error.message);
    return res.status(500).json({ success: false, error: "serverError" });
  }
};
export default authLoginController;
