import { Router } from "express";
import { body } from "express-validator";
import accountsControllers from "../controllers/accounts.controllers";
import handleValidationResult from "../middleware/handleValidationResult";
import validateToken from "../middleware/validateToken";

const accountsRouter = Router();

accountsRouter.post(
  "/api/accounts/",
  body("first_name").not().isEmpty(),
  body("last_name").not().isEmpty(),
  body("email").isEmail().normalizeEmail(),
  body("role").isIn(["coordinator", "boatManager"]),
  body("password").isLength({ min: 6 }),
  handleValidationResult,
  validateToken,
  accountsControllers.createAccountController
);
accountsRouter.get(
  "/api/accounts/",
  validateToken,
  accountsControllers.showAllAccounts
);

export default accountsRouter;
